import { defineConfig } from 'vite'
import { resolve } from 'path';
import vue from '@vitejs/plugin-vue'
import ViteComponents from 'unplugin-vue-components/vite'
import { AntDesignVueResolver } from 'unplugin-vue-components/resolvers';

const root = process.cwd()
// https://vitejs.dev/config/
export default defineConfig({
  root,
  css: {
    preprocessorOptions: {
      less: {
        // 解决antd 引入less报错
        javascriptEnabled: true,
        // TODO: 改为按需加载，但是目前样式无法覆盖
        lessOptions: {
          modifyVars: {
            'primary-color': '#a1c4fd'
          }
        }
      }
    }
  },
  resolve: {
    alias: [
      {
        find: /^@\//,
        replacement: resolve(root, './src') + '/'
      }
    ]
  },
  build: {
    terserOptions: {
      compress: {
        drop_console: true,
        drop_debugger: true
      }
    }
  },
  plugins: [
    vue(),
    ViteComponents({
      resolvers: [AntDesignVueResolver({
        importStyle: true,
        resolveIcons: true
      })],
      dts: true
    })
  ]
})
